==> ant-design-vue-2.0.0-rc.9.jar: META-INF/resources/webjars/ant-design-vue/2.0.0-rc.9/es/tabs/TabBar.d.ts <==
import { PropType } from 'vue';
declare const TabBar: import("vue").DefineComponent<{
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    centered: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    tabBarStyle: import("vue-types").VueTypeValidableDef<import("vue").CSSProperties>;
    tabBarExtraContent: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    type: import("vue-types").VueTypeDef<"line" | "card" | "editable-card">;
    tabPosition: import("vue-types").VueTypeDef<"bottom" | "left" | "right" | "top"> & {
        default: "bottom" | "left" | "right" | "top";
    };
    tabBarPosition: import("vue-types").VueTypeDef<"bottom" | "left" | "right" | "top">;
    size: import("vue-types").VueTypeDef<"default" | "small" | "large">;
    animated: {
        type: PropType<boolean | {
            inkBar: boolean;
            tabPane: boolean;
        }>;
        default: any;
    };
    renderTabBar: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    panels: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    } & {
        default: () => unknown[];
    };
    activeKey: import("vue-types").VueTypeDef<import("../_util/type").Key>;
    tabBarGutter: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    };
}, unknown, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    prefixCls: string;
    animated: boolean | {
        inkBar: boolean;
        tabPane: boolean;
    };
    centered: boolean;
    tabPosition: "bottom" | "left" | "right" | "top";
    renderTabBar: (...args: any[]) => any;
    panels: unknown[];
    tabBarGutter: number;
} & {
    size?: "default" | "small" | "large";
    type?: "line" | "card" | "editable-card";
    activeKey?: import("../_util/type").Key;
    tabBarStyle?: import("vue").CSSProperties;
    tabBarExtraContent?: import("../_util/type").VueNode;
    tabBarPosition?: "bottom" | "left" | "right" | "top";
}>, {
    prefixCls: string;
    animated: boolean | {
        inkBar: boolean;
        tabPane: boolean;
    };
    centered: boolean;
    tabPosition: "bottom" | "left" | "right" | "top";
    renderTabBar: (...args: any[]) => any;
    panels: unknown[];
    tabBarGutter: number;
}>;
export default TabBar;

==> ant-design-vue-2.1.3.jar: META-INF/resources/webjars/ant-design-vue/2.1.3/es/tabs/TabBar.d.ts <==
import { PropType } from 'vue';
declare const TabBar: import("vue").DefineComponent<{
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    centered: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    tabBarStyle: import("vue-types").VueTypeValidableDef<import("vue").CSSProperties>;
    tabBarExtraContent: import("vue-types").VueTypeValidableDef<import("../_util/type").VueNode>;
    type: import("vue-types").VueTypeDef<"line" | "card" | "editable-card">;
    tabPosition: import("vue-types").VueTypeDef<"left" | "right" | "bottom" | "top"> & {
        default: "left" | "right" | "bottom" | "top";
    };
    tabBarPosition: import("vue-types").VueTypeDef<"left" | "right" | "bottom" | "top">;
    size: import("vue-types").VueTypeDef<"default" | "small" | "large">;
    animated: {
        type: PropType<boolean | {
            inkBar: boolean;
            tabPane: boolean;
        }>;
        default: any;
    };
    renderTabBar: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    panels: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    } & {
        default: () => unknown[];
    };
    activeKey: import("vue-types").VueTypeDef<string | number>;
    tabBarGutter: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    };
}, unknown, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    prefixCls: string;
    animated: boolean | {
        inkBar: boolean;
        tabPane: boolean;
    };
    centered: boolean;
    tabPosition: "left" | "right" | "bottom" | "top";
    renderTabBar: (...args: any[]) => any;
    panels: unknown[];
    tabBarGutter: number;
} & {
    size?: "default" | "small" | "large";
    type?: "line" | "card" | "editable-card";
    activeKey?: string | number;
    tabBarStyle?: import("vue").CSSProperties;
    tabBarExtraContent?: import("../_util/type").VueNode;
    tabBarPosition?: "left" | "right" | "bottom" | "top";
}>, {
    prefixCls: string;
    animated: boolean | {
        inkBar: boolean;
        tabPane: boolean;
    };
    centered: boolean;
    tabPosition: "left" | "right" | "bottom" | "top";
    renderTabBar: (...args: any[]) => any;
    panels: unknown[];
    tabBarGutter: number;
}>;
export default TabBar;
